package com.yingxin.server.client;

import com.yingxin.server.client.Service.ClientService;
import com.yingxin.server.client.Service.Impl.ClientServiceImpl;
import com.yingxin.server.client.entities.Client;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.data.redis.connection.RedisConnectionFactory;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.security.oauth2.config.annotation.web.configuration.EnableAuthorizationServer;
import org.springframework.security.oauth2.provider.ClientDetailsService;
import org.springframework.security.oauth2.provider.ClientRegistrationException;
import org.springframework.security.oauth2.provider.OAuth2Authentication;
import org.springframework.security.oauth2.provider.client.BaseClientDetails;
import org.springframework.security.oauth2.provider.code.AuthorizationCodeServices;
import org.springframework.security.oauth2.provider.code.RandomValueAuthorizationCodeServices;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.concurrent.TimeUnit;


@EnableAuthorizationServer
@SpringBootApplication
public class ClientApplication {

	@Bean
	public ClientService clientService(){
		return new ClientServiceImpl();
	}

	@Bean
	public BCryptPasswordEncoder bCryptPasswordEncoder(){
		return new BCryptPasswordEncoder();
	}

	@Autowired
	BCryptPasswordEncoder bCryptPasswordEncoder;

	@Bean
	public ClientDetailsService myClientDetailsService(ClientService clientService) {
		return clientId -> {
			List<Client> clients1 = clientService.findClientByCLientId(clientId);
			if (clients1 == null || clients1.size() == 0) {
				throw new ClientRegistrationException("clientId无效");
			}
			Client client = clients1.get(0);
			String clientSecretAfterEncoder = bCryptPasswordEncoder.encode(client.getClientSecret());
			BaseClientDetails clientDetails = new BaseClientDetails();
			clientDetails.setClientId(client.getClientId());
			clientDetails.setClientSecret(clientSecretAfterEncoder);
			clientDetails.setRegisteredRedirectUri(new HashSet(Arrays.asList(client.getWebServerRedirectUri())));
			clientDetails.setAuthorizedGrantTypes(Arrays.asList(client.getAuthorizedGrantTypes().split(",")));
			clientDetails.setScope(Arrays.asList(client.getScope().split(",")));
			return clientDetails;
		};
	}

	public static void main(String[] args) {
		SpringApplication.run(ClientApplication.class, args);
	}

}
